==> vtigercrm-5.3.0p0.tgz: modules/PickList/language/pt_br.lang.php <==
<?php
/*********************************************************************************
** The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 * Contributor(s): Valmir Carlos Trindade/Translate to Brazilian Portuguese|20/10/2011|Curitiba/Paraná/Brasil.|www.ttcasolucoes.com.br
 ********************************************************************************/
/**
 * this file can be used to internationalise the strings present in the picklist
 */
$mod_strings = array(
	'LBL_ASSIGN_BUTTON'=>'Designar',
	'ADD_PICKLIST_VALUES'=>'Adicionar valores Lista Opções',
	'LBL_EXISTING_PICKLIST_VALUES'=>'Valores existentes Lista Opções',
	'LBL_PICKLIST_ADDINFO'=>'Adicionar nova entrada aqui',
	'LBL_SELECT_ROLES'=>'Selecionar Função',
	'LBL_NON_EDITABLE_PICKLIST_ENTRIES'=>'Valores não-editáveis',
	'EDIT_PICKLIST_VALUE'=>'Editar valores Lista Opções',
	'LBL_EDIT_HERE'=>'Substituir por: ',
	'LBL_SELECT_TO_EDIT'=>'Selecionar um valor para editar: ',
	'DELETE_PICKLIST_VALUES'=>'Apagar valores Lista Opções',
	'LBL_REPLACE_WITH'=>'Substituir por: ',
	'ASSIGN_PICKLIST_VALUES'=>'Designar Valores Lista Opções',
	'LBL_PICKLIST_VALUES'=>'Valores Lista Opções disponí­veis',
	'LBL_PICKLIST_VALUES_ASSIGNED_TO'=>'Valores Lista de Opções designados para ',
	'LBL_ADD_TO_OTHER_ROLES'=>'Adicionar outra Função',
	'LBL_OK_BUTTON_LABEL'=>'Ok',
	'LBL_SELECT_ROLES'=>'Selecionar Função',
	'LBL_DISPLAYED_VALUES'=>'Todos os valores acessíveis para a função apresentada abaixo',

	// For Dependency picklist
	'LBL_PICKLIST_DEPENDENCY_SETUP' => 'Configurar Dependência Lista Opções',
	'LBL_PICKLIST_DEPENDENCY_DESCRIPTION' => 'Configurar Dependência entre valores Lista Opções em cada módulo',
	'LBL_NEW_DEPENDENCY' => 'Nova Dependência Lista Opções',
	'LBL_TOOLS' => 'Ferramentas',
	'LBL_SOURCE_FIELD' => 'Campo Origem',
	'LBL_TARGET_FIELD' => 'Campo Alvo',
	'LBL_BUTTON_SELECTED_SOURCE_VALUES' => 'Selecionar Valores Origem',
	'LBL_SELECTED_SOURCE_VALUES_MSG' => 'Selecionar Valores Origem Lista Opções para configurar o mapeamento',
	'LBL_ERR_CYCLIC_DEPENDENCY' => 'Esta configuração de dependência não é permitida, pois termina em uma dependência cíclica',
	'LBL_SELECTED_VALUES' => 'Valores Selecionados',
	'LBL_CONFIGURE_DEPENDENCY_HELP_1' => 'Somente valores mapeados da Lista de Opções do campo Fonte serão mostrados abaixo (exceto na primeira vez)',
	'LBL_CONFIGURE_DEPENDENCY_HELP_2' => "Se você deseja visualizar ou alterar o mapeamento para os valores de outra Lista de Opções do campo Fonte, <br/>
										então poderá selecionar os valores clicando sobre o botão <b>'Selecionar valores Fonte'</b> no lado direito",
	'LBL_CONFIGURE_DEPENDENCY_HELP_3' => 'Os valores selecionados para os valores do campo Alvo, estão em destaque como',
);
?>

==> vtigercrm-5.4.0.tgz: modules/PickList/language/pt_br.lang.php <==
<?php
/*********************************************************************************
** The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 * Contributor(s): Valmir Carlos Trindade/Translate to Brazilian Portuguese| 13/04/2012 |Curitiba/Paraná/Brasil.|www.ttcasolucoes.com.br
 ********************************************************************************/
/**
 * this file can be used to internationalise the strings present in the picklist
 */
$mod_strings = array(
	'LBL_ASSIGN_BUTTON'=>'Designar',
	'ADD_PICKLIST_VALUES'=>'Adicionar valores Lista Opções',
	'LBL_EXISTING_PICKLIST_VALUES'=>'Valores existentes Lista Opções',
	'LBL_PICKLIST_ADDINFO'=>'Adicionar nova entrada aqui',
	'LBL_SELECT_ROLES'=>'Selecionar Função',
	'LBL_NON_EDITABLE_PICKLIST_ENTRIES'=>'Valores não-editáveis',
	'EDIT_PICKLIST_VALUE'=>'Editar valores Lista Opções',
	'LBL_EDIT_HERE'=>'Substituir por: ',
	'LBL_SELECT_TO_EDIT'=>'Selecionar um valor para editar: ',
	'DELETE_PICKLIST_VALUES'=>'Apagar valores Lista Opções',
	'LBL_REPLACE_WITH'=>'Substituir por: ',
	'ASSIGN_PICKLIST_VALUES'=>'Designar Valores Lista Opções',
	'LBL_PICKLIST_VALUES'=>'Valores Lista Opções disponí­veis',
	'LBL_PICKLIST_VALUES_ASSIGNED_TO'=>'Valores Lista de Opções designados para ',
	'LBL_ADD_TO_OTHER_ROLES'=>'Adicionar outra Função',
	'LBL_OK_BUTTON_LABEL'=>'Ok',
	'LBL_SELECT_ROLES'=>'Selecionar Função',
	'LBL_DISPLAYED_VALUES'=>'Todos os valores acessíveis para a função estão apresentados abaixo',

	// For Dependency picklist
	'LBL_PICKLIST_DEPENDENCY_SETUP' => 'Configurar Dependência Lista Opções',
	'LBL_PICKLIST_DEPENDENCY_DESCRIPTION' => 'Configurar Dependência entre valores Lista Opções em cada módulo',
	'LBL_NEW_DEPENDENCY' => 'Nova Dependência Lista Opções',
	'LBL_TOOLS' => 'Ferramentas',
	'LBL_SOURCE_FIELD' => 'Campo Origem',
	'LBL_TARGET_FIELD' => 'Campo Alvo',
	'LBL_BUTTON_SELECTED_SOURCE_VALUES' => 'Selecionar Valores Origem',
	'LBL_SELECTED_SOURCE_VALUES_MSG' => 'Selecionar Valores Origem Lista Opções para configurar o mapeamento',
	'LBL_ERR_CYCLIC_DEPENDENCY' => 'Esta configuração de dependência não é permitida, pois termina em uma dependência cíclica',
	'LBL_SELECTED_VALUES' => 'Valores Selecionados',
	'LBL_CONFIGURE_DEPENDENCY_HELP_1' => 'Somente valores mapeados da Lista de Opções do campo Fonte serão mostrados abaixo (exceto na primeira vez)',
	'LBL_CONFIGURE_DEPENDENCY_HELP_2' => "Se você deseja visualizar ou alterar o mapeamento para os valores de outra Lista de Opções do campo Fonte, <br/>
										então poderá selecionar os valores clicando sobre o botão <b>'Selecionar valores Fonte'</b> no lado direito",
	'LBL_CONFIGURE_DEPENDENCY_HELP_3' => 'Os valores selecionados para os valores do campo Alvo, estão em destaque como',
	'LBL_ADD_BUTTON' => 'Adicionar Item',
	'LBL_EDIT_BUTTON' => 'Renomear Item',
	'LBL_DELETE_BUTTON' => 'Apagar Item',
	'NTC_DELETE_CONFIRMATION'=>'Tem certeza que deseja apagar esta dependência da Lista de Opções?',
);
?>
